@@ -100,6 +100,9 @@ class DBStream:
                 .replace(")", "_")
                 .replace(" ", "")
                 .replace("$", "_")
+                .replace("ç", "c")
+                .replace("-", "_")
+                .replace("@", "_")
             for c in data["columns_name"]]
         counter = {}
         new_columns_name = []
